==> semantik_0.6.5.orig.tar.gz: semantik-0.6.5.orig/src/BnvzS_py.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL
#include <Python.h>

#include <QFile>
#include <QtDebug>
#include <QByteArray>
#include "BnvzS.h"
#include "tslabels.h"

PyObject *hzzqjt(const QString &meghat)
<%
	QByteArray adelk=meghat.toUtf8();
	PyObject *klsirz=PyString_FromStringAndSize(adelk.data(),adelk.size());
	return klsirz;
%>

QString fnqll(PyObject* tqrost)
<%
	if(!tqrost) return QString();

	int jlzpnt=PyString_Check(tqrost);
	if(!jlzpnt)
	<%
		return QString();
	%>

	int irnyjl=PyString_Size(tqrost);
	char * adelk=PyString_AsString(tqrost);

	QString mrtdt=QString::fromUtf8(adelk,irnyjl);
	return mrtdt;
%>

PyObject *eler(PyObject *meghat,PyObject *vnl)
<%
	bndkli *adelk=bndkli::instance();
	return PyCObject_FromVoidPtr(adelk,0);
%>

PyObject *mgmnkl(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	int num=0;
	if(!PyArg_ParseTuple(vnl,"Oi",&lnmtat,&num)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	bndkli *adelk=jlzpnt->kidlgz(num);
	return PyCObject_FromVoidPtr(adelk,0);
%>

PyObject *kket(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	int row=0; int col=0;
	if(!PyArg_ParseTuple(vnl,"Oii",&lnmtat,&row,&col)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	QString content=jlzpnt->prmz(row,col);
	return hzzqjt(content);
%>

PyObject *kidlgz(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	int num=jlzpnt->dolog();
	return Py_BuildValue("i",num);
%>

PyObject *felvnl(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	int num=jlzpnt->nybnvn();
	return Py_BuildValue("i",num);
%>

PyObject *fldlgz(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	int adelk=jlzpnt->megkap();
	return Py_BuildValue("i",adelk);
%>

PyObject *bprl(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	PyObject *irnyjl=0;
	if(!PyArg_ParseTuple(vnl,"OO",&lnmtat,&irnyjl)) <%  return 0; %>
	bndkli* klsirz =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	QString adelk=fnqll(irnyjl);
	QString mrtdt=klsirz->akdaly(adelk);
	return hzzqjt(mrtdt);
%>

PyObject *prmz(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	PyObject *irnyjl=0;
	PyObject *adelk=0;
	if(!PyArg_ParseTuple(vnl,"OOO",&lnmtat,&irnyjl,&adelk)) <%  return 0; %>
	bndkli* klsirz =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	QString mrtdt=fnqll(irnyjl);
	QString val=fnqll(adelk);
	klsirz->cel(mrtdt,val);
	return Py_None;
%>

PyObject *kitzjl(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	QString adelk=fnqll(lnmtat);
	QString mrtdt=bndkli::zandek(adelk);
	return hzzqjt(mrtdt);
%>

PyObject *jlzpnt(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	PyObject *irnyjl=0;
	if(!PyArg_ParseTuple(vnl,"OO",&lnmtat,&irnyjl)) <%  return 0; %>
	QString mrtdt=fnqll(lnmtat);
	QString adelk=fnqll(irnyjl);

	bndkli::kivalt(mrtdt,adelk);
	return Py_None;
%>

PyObject *irnyjl(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	QString mrtdt=fnqll(lnmtat);
	QString klsirz=bndkli::protectXML(mrtdt);
	return hzzqjt(klsirz);
%>

PyObject *adelk(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	QString mrtdt=fnqll(lnmtat);
	QString klsirz=bndkli::protectHTML(mrtdt);
	return hzzqjt(klsirz);
%>

static PyMethodDef methods[]=<%
	<%"child_count",kidlgz,METH_VARARGS,0%>,
	<%"child_num",  mgmnkl,METH_VARARGS,0%>,
	<%"get_val",  bprl,METH_VARARGS,0%>,
	<%"set_val",  prmz,METH_VARARGS,0%>,

	<%"num_rows",felvnl,METH_VARARGS,0%>,
	<%"num_cols",fldlgz,METH_VARARGS,0%>,
	<%"get_cell",kket,METH_VARARGS,0%>,

	<%"instance",eler,METH_VARARGS,0%>,
	<%"get_var", kitzjl,METH_VARARGS,0%>,
	<%"set_var", jlzpnt,METH_VARARGS,0%>,

	<%"protectXML",irnyjl,METH_VARARGS,0%>,
	<%"protectHTML",adelk,METH_VARARGS,0%>,

	<% 0,0,0,0 %>
%>;

int prl()
<%
	if(Py_IsInitialized()) return 1;

	Py_Initialize();
	Py_InitModule("sembind",methods);
	QFile klsirz(":BnvzS.py");
	if(!klsirz.open(QIODevice::ReadOnly)) return 0;
	QByteArray cel=klsirz.readAll();
	klsirz.close();
	PyRun_SimpleString(cel.constData());

	return 1;
%>

==> semantik_0.6.8.orig.tar.gz: semantik-0.6.8.orig/src/BnvzS_py.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL
#include <Python.h>

#include <aux.h>
#include <QFile>
#include <QtDebug>
#include <QByteArray>
#include "BnvzS.h"
#include "tslabels.h"

PyObject *hzzqjt(const QString &meghat)
<%
	QByteArray adelk=meghat.toUtf8();
	PyObject *klsirz=PyString_FromStringAndSize(adelk.data(),adelk.size());
	return klsirz;
%>

QString fnqll(PyObject* tqrost)
<%
	if(!tqrost) return QString();

	int jlzpnt=PyString_Check(tqrost);
	if(!jlzpnt)
	<%
		return QString();
	%>

	int irnyjl=PyString_Size(tqrost);
	char * adelk=PyString_AsString(tqrost);

	QString mrtdt=QString::fromUtf8(adelk,irnyjl);
	return mrtdt;
%>

PyObject *eler(PyObject *meghat,PyObject *vnl)
<%
	bndkli *adelk=bndkli::instance();
	return PyCObject_FromVoidPtr(adelk,0);
%>

PyObject *mgmnkl(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	int num=0;
	if(!PyArg_ParseTuple(vnl,"Oi",&lnmtat,&num)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	bndkli *adelk=jlzpnt->kidlgz(num);
	return PyCObject_FromVoidPtr(adelk,0);
%>

PyObject *kket(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	int row=0; int col=0;
	if(!PyArg_ParseTuple(vnl,"Oii",&lnmtat,&row,&col)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	QString content=jlzpnt->prmz(row,col);
	return hzzqjt(content);
%>

PyObject *kidlgz(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	int num=jlzpnt->dolog();
	return Py_BuildValue("i",num);
%>

PyObject *felvnl(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	int num=jlzpnt->nybnvn();
	return Py_BuildValue("i",num);
%>

PyObject *fldlgz(PyObject *meghat,PyObject *vnl)
<%
	PyObject * lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	bndkli *jlzpnt =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	int adelk=jlzpnt->megkap();
	return Py_BuildValue("i",adelk);
%>

PyObject *bprl(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	PyObject *irnyjl=0;
	if(!PyArg_ParseTuple(vnl,"OO",&lnmtat,&irnyjl)) <%  return 0; %>
	bndkli* klsirz =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	QString adelk=fnqll(irnyjl);
	QString mrtdt=klsirz->akdaly(adelk);
	return hzzqjt(mrtdt);
%>

PyObject *prmz(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	PyObject *irnyjl=0;
	PyObject *adelk=0;
	if(!PyArg_ParseTuple(vnl,"OOO",&lnmtat,&irnyjl,&adelk)) <%  return 0; %>
	bndkli* klsirz =(bndkli*) PyCObject_AsVoidPtr(lnmtat);
	QString mrtdt=fnqll(irnyjl);
	QString val=fnqll(adelk);
	klsirz->cel(mrtdt,val);
	return Py_None;
%>

PyObject *kitzjl(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	QString adelk=fnqll(lnmtat);
	QString mrtdt=bndkli::fladat(adelk);
	return hzzqjt(mrtdt);
%>

PyObject *jlzpnt(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	PyObject *irnyjl=0;
	if(!PyArg_ParseTuple(vnl,"OO",&lnmtat,&irnyjl)) <%  return 0; %>
	QString mrtdt=fnqll(lnmtat);
	QString adelk=fnqll(irnyjl);

	bndkli::kivalt(mrtdt,adelk);
	return Py_None;
%>

PyObject *irnyjl(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	QString mrtdt=fnqll(lnmtat);
	QString klsirz=bndkli::protectXML(mrtdt);
	return hzzqjt(klsirz);
%>

PyObject *adelk(PyObject *meghat,PyObject *vnl)
<%
	PyObject *lnmtat=0;
	if(!PyArg_ParseTuple(vnl,"O",&lnmtat)) <%  return 0; %>
	QString mrtdt=fnqll(lnmtat);
	QString klsirz=bndkli::protectHTML(mrtdt);
	return hzzqjt(klsirz);
%>

static PyMethodDef methods[]=<%
	<%"child_count",kidlgz,METH_VARARGS,0%>,
	<%"child_num",  mgmnkl,METH_VARARGS,0%>,
	<%"get_val",  bprl,METH_VARARGS,0%>,
	<%"set_val",  prmz,METH_VARARGS,0%>,

	<%"num_rows",felvnl,METH_VARARGS,0%>,
	<%"num_cols",fldlgz,METH_VARARGS,0%>,
	<%"get_cell",kket,METH_VARARGS,0%>,

	<%"instance",eler,METH_VARARGS,0%>,
	<%"get_var", kitzjl,METH_VARARGS,0%>,
	<%"set_var", jlzpnt,METH_VARARGS,0%>,

	<%"protectXML",irnyjl,METH_VARARGS,0%>,
	<%"protectHTML",adelk,METH_VARARGS,0%>,

	<% 0,0,0,0 %>
%>;

int prl()
<%
	if(Py_IsInitialized()) return 1;

	Py_Initialize();
	Py_InitModule("sembind",methods);
	QFile klsirz(SEMANTIK_DIR "/sembind.py");
	if(!klsirz.open(QIODevice::ReadOnly)) <% return 0; %>
	QByteArray akdaly=klsirz.readAll();
	klsirz.close();
	PyRun_SimpleString(akdaly.constData());

	return 1;
%>
